@@ -176,55 +176,13 @@ def pull_repo(directory, branch):
     else:
         print(f"\nError pulling repository: {process.stderr.read()}")
 
-def generate_test_cases(file_path):
-    # Read the code from the specified file
-    try:
-        with open(file_path, 'r') as file:
-            code_snippet = file.read()
-    except FileNotFoundError:
-        print(f"Error: The file '{file_path}' was not found.")
-        return
-    except Exception as e:
-        print(f"Error reading file: {e}")
-        return
-    
-    # Prepare the payload for the remote server
-    payload = {
-        "model": "llama3:8b",
-        "messages": [
-            {
-                "role": "system",
-                "content": f"Please generate detailed unit and integration test cases for the following code snippet:\n```{code_snippet}```"
-            }
-        ],
-        "stream": False  # Assuming the server handles non-streaming requests
-    }
-    
-    remote_server_url = "http://192.168.138.224:11434/api/chat"
-    
-    try:
-        # Execute the request to the remote server
-        response = requests.post(remote_server_url, json=payload)
-        response.raise_for_status()  # Raise an error for bad responses
-        output = response.json().get('message', {}).get('content', '')
-    except requests.RequestException as e:
-        print(f"Error executing request: {e}")
-        return
-    except Exception as e:
-        print(f"Unexpected error: {e}")
-        return
-    
-    # Print the generated test cases
-    print("Generated Test Cases:")
-    print(output)
-
 def main():
     if not check_ollama_installed():
         print("Ollama is not installed. Installing...")
         install_pack()
 
     print("What are you up to work with?")
-    print(" (1) Remote Repository\n (2) Local Repository\n (3) Generate Test Case")
+    print(" (1) Git Repository\n (2) Local Repository")
     repo_choice = input("Choice : ").strip().lower()
 
     if repo_choice == '1':
@@ -246,16 +204,12 @@ def main():
             print(f"The directory '{directory}' does not exist or is not a valid directory.")
             sys.exit(1)
         paragraphs = parse_file(directory)
-    elif repo_choice == '3':
-        file_path = input("Enter the file path to generate test cases from: ").strip()
-        generate_test_cases(file_path)
-        return  # Exit after generating test cases
     else:
         print("Invalid choice.")
         sys.exit(1)
 
     print("Select model type:")
-    print(" (1) Remote Repository\n (2) Local Repository\n (3) Generate Test Case")
+    print(" (1) Local Model\n (2) GPU Model")
     model_choice = input("Choice : ").strip().lower()
 
     if model_choice == '1':
@@ -263,12 +217,12 @@ def main():
         pull_images(modelname)
     elif model_choice == '2':
         modelname = select_model_based_on_ram()
-  
-
+        print(f"Selected remote model: {modelname}")
     else:
         print("Invalid choice.")
         sys.exit(1)
 
+    print(f"Selected model: {modelname}")
 
     embeddings = get_embeddings(directory.replace('/', '_'), modelname, paragraphs)
 
